@@ -6,66 +6,103 @@ arg                 =
 assert              =
 '引数 v が偽（i.e., `nil` または `false`）の場合、エラーを発生させる。それ以外の場合は、すべての引数を返えす。エラーが発生した際、`message` がエラーオブジェクトになる。`message` が指定されていない場合、デフォルトでエラーオブジェクトが `"assertion failed!"` になる。'
 
-cgopt.collect       =
-'完全なガベージコレクションサイクルを実行する。'
-cgopt.stop          =
-'自動実行を停止する。'
-cgopt.restart       =
-'自動実行を再開する。'
-cgopt.count         =
-'利用されているメモリ量の合計をキロバイト単位で返す。'
-cgopt.step          =
+collectgarbage51    =
 [[
-ガベージコレクションのステップを実行します。このオプションの後には整数 `size` を付けることができます。
-`size` が正の n の場合、コレクタは n バイトが新たに割り当てられたかのように動作します。`size` が 0 の場合、基本ステップを実行します。
-インクリメンタルモードでは、基本ステップは現在のステップサイズに対応します。世代別モードでは、基本ステップは完全なマイナー収集、
-またはコレクタがインクリメンタルステップを予定している場合はそのインクリメンタルステップを実行します。
-インクリメンタルモードでは、ステップが収集サイクルを完了した場合に `true` を返します。世代別モードでは、ステップがメジャー収集を完了した場合に `true` を返します。
-]]
-cgopt.setpause      =
-'`pause` の値を設定する。'
-cgopt.setstepmul    =
-'`step multiplier` の値を設定する。'
-cgopt.incremental   =
-'モードをインクリメンタルに変更し、以前のモード（`"generational"` または `"incremental"`）を返します。'
-cgopt.generational  =
-'モードを世代別に変更し、以前のモード（`"generational"` または `"incremental"`）を返します。'
-cgopt.param         =
-[[
-コレクタのパラメータの値を変更／取得します。このオプションの後には 1 つまたは 2 つの追加引数が必要です：
-対象パラメータ名（文字列）と、オプションの新しい値（[0,100000] の範囲の整数）。
-呼び出しは常にそのパラメータの「以前の値」を返します。新しい値が与えられない場合、値は変更されません。Lua はこれらの値を圧縮形式で保存するため、
-返される以前の値は最後に設定された値と完全には一致しない場合があります。
+この関数はガベージコレクタへの汎用インターフェースです。最初の引数 opt に応じて、さまざまな機能を実行します：
+
+* `"collect"`：完全なガベージコレクションサイクルを実行します。これがデフォルトオプションです。
+* `"stop"`：ガベージコレクタを停止します。
+* `"restart"`：ガベージコレクタを再起動します。
+* `"count"`：Lua が使用しているメモリの合計（キロバイト単位）を返します。
+* `"step"`：ガベージコレクションステップを実行します。ステップの「サイズ」は arg によって制御されます（より大きな値はより多くのステップを意味します）が、具体的な方法は規定されていません。ステップサイズを制御したい場合は、arg の値を実験的に調整する必要があります。ステップが収集サイクルを完了した場合、true を返します。
+* `"setpause"`：arg をコレクタの一時停止の新しい値として設定します（§2.10 参照）。一時停止の以前の値を返します。
+* `"setstepmul"`：arg をコレクタのステップ乗数の新しい値として設定します（§2.10 参照）。ステップ乗数の以前の値を返します。
 ]]
 
-gcparam.minormul    =
-'マイナー乗数。'
-gcparam.majorminor  =
-'メジャー・マイナー乗数。'
-gcparam.minormajor  =
-'マイナー・メジャー乗数。'
-gcparam.pause       =
-'ガベージコレクターの一時停止。'
-gcparam.stepmul     =
-'ステップ乗数。'
-gcparam.stepsize    =
-'ステップサイズ。'
-
-cgopt.isrunning     =
-'ガベージコレクションが実行中かどうかを返す。'
-
-collectgarbage      =
+collectgarbage52    =
 [[
-ガベージコレクタへの汎用インターフェース。第1引数 `opt` によって次を実行します：
-• `"collect"`: 完全なガベージコレクションサイクルを実行（デフォルト）。
-• `"stop"`: コレクタの自動実行を停止；`"restart"` まで明示的に呼び出したときのみ実行。
-• `"restart"`: コレクタの自動実行を再開。
-• `"count"`: Lua が使用しているメモリ総量を KBytes で返す（小数あり；1024 を掛けるとバイト数）。
-• `"step"`: ガベージコレクションのステップを実行；整数 `size` により動作と戻り値が制御される（`cgopt.step` 参照）。
-• `"isrunning"`: コレクタが実行中かどうか（停止されていないか）を返す。
-• `"incremental"`: インクリメンタルモードに変更し、以前のモードを返す。
-• `"generational"`: 世代別モードに変更し、以前のモードを返す。
-• `"param"`: コレクタのパラメータを変更／取得（`gcparam.*` 参照）。常に以前の値を返す。
+この関数はガベージコレクタへの汎用インターフェースです。最初の引数 opt に応じて、さまざまな機能を実行します：
+
+* `"collect"`：完全なガベージコレクションサイクルを実行します。これがデフォルトオプションです。
+* `"stop"`：ガベージコレクタの自動実行を停止します。コレクタは明示的に呼び出された場合にのみ実行され、再起動の呼び出しまで続きます。
+* `"restart"`：ガベージコレクタの自動実行を再開します。
+* `"count"`：Lua が使用しているメモリの合計（キロバイト単位）と、メモリの総バイト数を 1024 で割った余りを示す 2 番目の値を返します。最初の値には小数部分があるため、次の等式は常に真です：
+    ```lua
+     k, b = collectgarbage("count")
+     assert(k*1024 == math.floor(k)*1024 + b)
+     ```
+    （Lua が数値に非浮動小数点型でコンパイルされている場合、2 番目の結果が役立ちます。）
+* `"step"`：ガベージコレクションステップを実行します。ステップの「サイズ」は arg によって制御されます（より大きな値はより多くのステップを意味します）が、具体的な方法は規定されていません。ステップサイズを制御したい場合は、arg の値を実験的に調整する必要があります。ステップが収集サイクルを完了した場合、true を返します。
+* `"setpause"`：arg をコレクタの一時停止の新しい値として設定します（§2.5 参照）。一時停止の以前の値を返します。
+* `"setstepmul"`：arg をコレクタのステップ乗数の新しい値として設定します（§2.5 参照）。ステップ乗数の以前の値を返します。
+* `"isrunning"`：コレクタが実行中かどうか（つまり、停止されていないか）を示すブール値を返します。
+* `"generational"`：コレクタを世代別モードに変更します。これは実験的な機能です（§2.5 参照）。
+* `"incremental"`：コレクタをインクリメンタルモードに変更します。これがデフォルトモードです。
+]]
+
+collectgarbage53    =
+[[
+この関数はガベージコレクタへの汎用インターフェースです。最初の引数 opt に応じて、さまざまな機能を実行します：
+
+* `"collect"`：完全なガベージコレクションサイクルを実行します。これがデフォルトオプションです。
+* `"stop"`：ガベージコレクタの自動実行を停止します。コレクタは明示的に呼び出された場合にのみ実行され、再起動の呼び出しまで続きます。
+* `"restart"`：ガベージコレクタの自動実行を再開します。
+* `"count"`：Lua が使用しているメモリの合計をキロバイト単位で返します。値には小数部分があり、1024 を掛けると Lua が使用している正確なバイト数が得られます（オーバーフローを除く）。
+* `"step"`：ガベージコレクションステップを実行します。ステップの「サイズ」は arg によって制御されます。値がゼロの場合、コレクタは 1 つの基本（不可分な）ステップを実行します。ゼロ以外の値の場合、コレクタはその量のメモリ（キロバイト単位）が Lua によって割り当てられたかのように動作します。ステップが収集サイクルを完了した場合、true を返します。
+* `"setpause"`：arg をコレクタの一時停止の新しい値として設定します（§2.5 参照）。一時停止の以前の値を返します。
+* `"setstepmul"`：arg をコレクタのステップ乗数の新しい値として設定します（§2.5 参照）。ステップ乗数の以前の値を返します。
+* "isrunning"`：コレクタが実行中かどうか（つまり、停止されていないか）を示すブール値を返します。
+]]
+
+collectgarbage54    =
+[[
+この関数はガベージコレクタへの汎用インターフェースです。最初の引数 opt に応じて、さまざまな機能を実行します：
+
+* `"collect"`：完全なガベージコレクションサイクルを実行します。これがデフォルトオプションです。
+* `"stop"`：ガベージコレクタの自動実行を停止します。コレクタは明示的に呼び出された場合にのみ実行され、再起動の呼び出しまで続きます。
+* `"restart"`：ガベージコレクタの自動実行を再開します。
+* `"count"`：Lua が使用しているメモリの合計をキロバイト単位で返します。値には小数部分があり、1024 を掛けると Lua が使用している正確なバイト数が得られます。
+* `"step"`：ガベージコレクションステップを実行します。ステップの「サイズ」は arg によって制御されます。値がゼロの場合、コレクタは 1 つの基本（不可分な）ステップを実行します。ゼロ以外の値の場合、コレクタはその量のメモリ（キロバイト単位）が Lua によって割り当てられたかのように動作します。ステップが収集サイクルを完了した場合、true を返します。
+* `"isrunning"`：コレクタが実行中かどうか（つまり、停止されていないか）を示すブール値を返します。
+* `"incremental"`：コレクタモードをインクリメンタルに変更します。このオプションの後には 3 つの数値を続けることができます：ガベージコレクタの一時停止、ステップ乗数、およびステップサイズ（§2.5.1 参照）。ゼロはその値を変更しないことを意味します。
+* `"generational"`：コレクタモードを世代別に変更します。このオプションの後には 2 つの数値を続けることができます：ガベージコレクタのマイナー乗数とメジャー乗数（§2.5.2 参照）。ゼロはその値を変更しないことを意味します。
+ガベージコレクションとこれらのオプションの一部の詳細については、§2.5 を参照してください。
+
+この関数はファイナライザから呼び出すべきではありません。
+]]
+
+collectgarbage55    =
+[[
+この関数はガベージコレクタへの汎用インターフェースです。最初の引数 opt に応じて、さまざまな機能を実行します：
+
+* `"collect"`：完全なガベージコレクションサイクルを実行します。これがデフォルトオプションです。
+* `"stop"`：ガベージコレクタの自動実行を停止します。コレクタは明示的に呼び出された場合にのみ実行され、再起動の呼び出しまで続きます。
+* `"restart"`：ガベージコレクタの自動実行を再開します。
+* `"count"`：Lua が使用しているメモリの合計をキロバイト単位で返します。値には小数部分があり、1024 を掛けると Lua が使用している正確なバイト数が得られます。
+* `"step"`：ガベージコレクションステップを実行します。このオプションの後には、ステップサイズを示す整数の追加引数を続けることができます。
+
+    サイズが正の n の場合、コレクタは n 個の新しいバイトが割り当てられたかのように動作します。サイズがゼロの場合、コレクタは基本ステップを実行します。インクリメンタルモードでは、基本ステップは現在のステップサイズに対応します。世代別モードでは、基本ステップは完全なマイナーコレクション、またはコレクタがスケジュールしている場合はインクリメンタルステップを実行します。
+
+    インクリメンタルモードでは、ステップが収集サイクルを完了した場合、関数は true を返します。世代別モードでは、ステップがメジャーコレクションを完了した場合、関数は true を返します。
+
+* `"isrunning"`：コレクタが実行中かどうか（つまり、停止されていないか）を示すブール値を返します。
+* `"incremental"`：コレクタモードをインクリメンタルに変更し、以前のモードを返します。
+* `"generational"`：コレクタモードを世代別に変更し、以前のモードを返します。
+* `"param"`：コレクタのパラメータの値を変更および/または取得します。このオプションの後には、1 つまたは 2 つの追加引数を続ける必要があります：変更または取得されるパラメータの名前（文字列）と、そのパラメータのオプションの新しい値（[0,100000] の範囲の整数）。最初の引数は次のいずれかの値である必要があります：
+    * `"minormul"`：マイナー乗数。
+    * `"majorminor"`：メジャー-マイナー乗数。
+    * `"minormajor"`：マイナー-メジャー乗数。
+    * `"pause"`：ガベージコレクタの一時停止。
+    * `"stepmul"`：ステップ乗数。
+    * `"stepsize"`：ステップサイズ。
+
+    呼び出しは常にパラメータの以前の値を返します。呼び出しが新しい値を提供しない場合、値は変更されません。
+
+    Lua はこれらの値を圧縮形式で保存するため、以前の値として返される値は、最後に設定された値と完全には一致しない場合があります。
+
+ガベージコレクションとこれらのオプションの一部の詳細については、§2.5 を参照してください。
+
+この関数はファイナライザから呼び出すべきではありません。
 ]]
 
 dofile              =
@@ -681,6 +718,10 @@ string.dump                 =
 '指定した関数をバイナリ形式（*バイナリコードブロック*）で表した文字列を返す。'
 string.find                 =
 '文字列の中から `pattern` に最初にマッチした部分を探す（§6.4.1 を参照）。マッチしたものが見つかった場合、マッチした部分の最初と最後のインデックスを返す。見つからなかった場合、`nil` を返す。'
+string.find['>5.2']         =
+'文字列中で `pattern`（§6.4.1 参照）に最初にマッチする部分を探します。'
+string.find['=5.1']         =
+'文字列中で `pattern`（§5.4.1 参照）に最初にマッチする部分を探します。'
 string.format               =
 '第一引数で指定されたフォーマットに沿って、可変数の引数を成形したものを返す。'
 string.gmatch               =
@@ -697,6 +738,34 @@ string.gmatch               =
 ]]
 string.gsub                 =
 '文字列 `s` の中の `pattern` にマッチした部分をすべて `repl` に置き換えた文字列を返す（§6.4.1 を参照）。`n` が指定された場合、最初にマッチした `n` 個の部分のみを置き換える。'
+string.gmatch['>5.2']       =
+[[
+呼び出されるたびに、文字列 `s` の中で `pattern`（§6.4.1 参照）に次にマッチするキャプチャを返すイテレータ関数を返します。
+
+例として、次のループは文字列 `s` 内のすべての単語を走査し、1行ずつ出力します:
+```lua
+    s = "hello world from Lua"
+    for w in string.gmatch(s, "%a+") do
+        print(w)
+    end
+```
+]]
+string.gmatch['=5.1']       =
+[[
+呼び出されるたびに、文字列 `s` の中で `pattern`（§5.4.1 参照）に次にマッチするキャプチャを返すイテレータ関数を返します。
+
+例として、次のループは文字列 `s` 内のすべての単語を走査し、1行ずつ出力します:
+```lua
+    s = "hello world from Lua"
+    for w in string.gmatch(s, "%a+") do
+        print(w)
+    end
+```
+]]
+string.gsub['>5.2']         =
+'文字列 `s` の中で `pattern`（§6.4.1 参照）にマッチした部分をすべて（または `n` を指定した場合は先頭 `n` 件）`repl` で置き換えた文字列を返します。'
+string.gsub['=5.1']         =
+'文字列 `s` の中で `pattern`（§5.4.1 参照）にマッチした部分をすべて（または `n` を指定した場合は先頭 `n` 件）`repl` で置き換えた文字列を返します。'
 string.len                  =
 '文字列の長さを返す。'
 string.lower                =
@@ -707,6 +776,14 @@ string.pack                 =
 '第一引数で指定されたフォーマットに沿って、可変数の引数をバイナリ文字列にシリアライズしたものを返す（§6.4.2 を参照）。'
 string.packsize             =
 '指定されたフォーマットを用いて`string.pack`によって生成された文字列の長さを返す。フォーマット文字列には可変長オプション `s` または `z` を含めることはできない（§6.4.2 を参照）。'
+string.match['>5.2']        =
+'文字列中で `pattern`（§6.4.1 参照）に最初にマッチする部分を探します。'
+string.match['=5.1']        =
+'文字列中で `pattern`（§5.4.1 参照）に最初にマッチする部分を探します。'
+string.pack['>5.2']         =
+'フォーマット文字列 `fmt`（§6.4.2 参照）に従って値 `v1`, `v2` などをバイナリ文字列としてシリアライズして返します。'
+string.packsize['>5.2']     =
+'指定したフォーマット `fmt`（§6.4.2 参照）で `string.pack` が生成する文字列のサイズを返します。'
 string.rep['>5.2']          =
 '`n` 個の文字列 `s` を文字列 `sep` で区切って連結した文字列を返す。デフォルトの `sep` は空文字列。`n` が正数でない場合は空文字列を返す。'
 string.rep['<5.1']          =
@@ -764,18 +841,18 @@ table.foreachi              =
 ]]
 table.getn                  =
 'テーブルの長さを返す。`#list` と同等。'
-table.new                   = -- TODO: need translate!
-[[This creates a pre-sized table, just like the C API equivalent `lua_createtable()`. This is useful for big tables if the final table size is known and automatic table resizing is too expensive. `narray` parameter specifies the number of array-like items, and `nhash` parameter specifies the number of hash-like items. The function needs to be required before use.
+table.new                   =
+[[C API の `lua_createtable()` と同様に、事前サイズ指定のテーブルを作成します。最終サイズが分かっていて自動リサイズがコスト高な大きなテーブルに有効です。`narray` は配列部分の要素数ヒント、`nhash` はハッシュ部分の要素数ヒントです。使用前に require が必要です。
 ```lua
     require("table.new")
 ```
 ]]
-table.clear                 = -- TODO: need translate!
-[[This clears all keys and values from a table, but preserves the allocated array/hash sizes. This is useful when a table, which is linked from multiple places, needs to be cleared and/or when recycling a table for use by the same context. This avoids managing backlinks, saves an allocation and the overhead of incremental array/hash part growth. The function needs to be required before use.
+table.clear                 =
+[[テーブルの全キーと値を消去しますが、割り当て済みの配列/ハッシュ領域は保持します。複数箇所から参照されるテーブルをクリアする場合や、同じコンテキストで再利用する場合に有用で、バックリンク管理や再割り当て・漸増拡張のオーバーヘッドを避けられます。使用前に require が必要です。
 ```lua
     require("table.clear").
 ```
-Please note this function is meant for very specific situations. In most cases it's better to replace the (usually single) link with a new table and let the GC do its work.
+この関数はごく限られたケース向けです。多くの場合はリンク先を新しいテーブルに置き換え、GC に任せる方が適切です。
 ]]
 
 utf8                        =
