@@ -6,65 +6,103 @@ arg                 =
 assert              =
 '如果其参数 `v` 的值为假（`nil` 或 `false`）， 它就调用 $error； 否则，返回所有的参数。 在错误情况时， `message` 指那个错误对象； 如果不提供这个参数，参数默认为 `"assertion failed!"` 。'
 
-cgopt.collect       =
-'做一次完整的垃圾收集循环。'
-cgopt.stop          =
-'停止垃圾收集器的运行。'
-cgopt.restart       =
-'重启垃圾收集器的自动运行。'
-cgopt.count         =
-'以 K 字节数为单位返回 Lua 使用的总内存数。'
-cgopt.step          =
+collectgarbage51    =
 [[
-执行一次垃圾收集的“步骤”。此选项后可以带一个额外参数 `size`（整数）。
-如果 `size` 为正的 n，收集器的行为就像新分配了 n 个字节；如果为 0，则执行一个“基本步骤”。
-在增量模式下，基本步骤对应当前的步进大小；在分代模式下，基本步骤会执行一次完整的次要收集，
-或在收集器已安排增量步骤时执行该增量步骤。
-在增量模式下，如果该步骤完成了一个收集周期，函数返回 `true`；在分代模式下，如果该步骤完成了一个主要收集，返回 `true`。
-]]
-cgopt.setpause      =
-'将 `arg` 设为收集器的 *间歇率* 。'
-cgopt.setstepmul    =
-'将 `arg` 设为收集器的 *步进倍率* 。'
-cgopt.incremental   =
-'将收集器模式改为“增量模式”，并返回之前的模式（可能是 `"generational"` 或 `"incremental"`）。'
-cgopt.generational  =
-'将收集器模式改为“分代模式”，并返回之前的模式（可能是 `"generational"` 或 `"incremental"`）。'
-cgopt.isrunning     =
-'返回表示收集器是否在工作的布尔值。'
-cgopt.param         =
-[[
-更改和/或检索收集器参数的值。此选项后必须跟一个或两个额外参数：
-要更改或检索的参数名称（字符串），以及该参数的可选新值（范围 [0,100000] 的整数）。
-调用总是返回该参数的“先前值”；如果未提供新值，则保持不变。Lua 以压缩格式存储这些值，
-因此返回的先前值可能不完全等于上次设置的值。
+此函数是垃圾收集器的通用接口。根据其第一个参数 opt 执行不同的功能：
+
+* `"collect"`：执行一个完整的垃圾收集周期。这是默认选项。
+* `"stop"`：停止垃圾收集器。
+* `"restart"`：重启垃圾收集器。
+* `"count"`：返回 Lua 使用的总内存数（以 K 字节为单位）。
+* `"step"`：执行一次垃圾收集步骤。步骤的"大小"由 arg 控制（较大的值表示更多步骤），具体方式未指定。如果要控制步骤大小，必须通过实验调整 arg 的值。如果步骤完成了一个收集周期则返回 true。
+* `"setpause"`：将 arg 设置为收集器间歇率的新值（参见 §2.10）。返回间歇率的先前值。
+* `"setstepmul"`：将 arg 设置为收集器步进倍率的新值（参见 §2.10）。返回步进倍率的先前值。
 ]]
 
-gcparam.minormul    =
-'次要乘数。'
-gcparam.majorminor  =
-'主要-次要乘数。'
-gcparam.minormajor  =
-'次要-主要乘数。'
-gcparam.pause       =
-'垃圾收集器暂停。'
-gcparam.stepmul     =
-'步进乘数。'
-gcparam.stepsize    =
-'步进大小。'
-
-collectgarbage      =
+collectgarbage52    =
 [[
-该函数是垃圾收集器的通用接口，根据第一个参数 `opt` 执行不同的功能：
-• `"collect"`：执行一次完整的垃圾收集循环（默认选项）。
-• `"stop"`：停止垃圾收集器的自动执行；之后仅在显式调用时运行，直到 `"restart"`。
-• `"restart"`：重启垃圾收集器的自动执行。
-• `"count"`：返回 Lua 当前使用的总内存（单位为 K字节，含小数；乘以 1024 得到字节数）。
-• `"step"`：执行一次垃圾收集步骤，可选参数 `size` 控制步长；行为与返回值见 `cgopt.step` 的说明。
-• `"isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未被停止）。
-• `"incremental"`：将模式改为增量模式，并返回之前的模式。
-• `"generational"`：将模式改为分代模式，并返回之前的模式。
-• `"param"`：更改/检索收集器参数（见各 `gcparam.*` 项），总是返回该参数的先前值。
+此函数是垃圾收集器的通用接口。根据其第一个参数 opt 执行不同的功能：
+
+* `"collect"`：执行一个完整的垃圾收集周期。这是默认选项。
+* `"stop"`：停止垃圾收集器的自动执行。收集器将仅在显式调用时运行，直到调用重启它。
+* `"restart"`：重启垃圾收集器的自动执行。
+* `"count"`：返回 Lua 使用的总内存数（以 K 字节为单位）和第二个值，表示总内存字节数模 1024。第一个值有小数部分，因此以下等式始终为真：
+    ```lua
+     k, b = collectgarbage("count")
+     assert(k*1024 == math.floor(k)*1024 + b)
+     ```
+    （当 Lua 使用非浮点类型编译数字时，第二个结果很有用。）
+* `"step"`：执行一次垃圾收集步骤。步骤的"大小"由 arg 控制（较大的值表示更多步骤），具体方式未指定。如果要控制步骤大小，必须通过实验调整 arg 的值。如果步骤完成了一个收集周期则返回 true。
+* `"setpause"`：将 arg 设置为收集器间歇率的新值（参见 §2.5）。返回间歇率的先前值。
+* `"setstepmul"`：将 arg 设置为收集器步进倍率的新值（参见 §2.5）。返回步进倍率的先前值。
+* `"isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未停止）。
+* `"generational"`：将收集器更改为分代模式。这是一个实验性功能（参见 §2.5）。
+* `"incremental"`：将收集器更改为增量模式。这是默认模式。
+]]
+
+collectgarbage53    =
+[[
+此函数是垃圾收集器的通用接口。根据其第一个参数 opt 执行不同的功能：
+
+* `"collect"`：执行一个完整的垃圾收集周期。这是默认选项。
+* `"stop"`：停止垃圾收集器的自动执行。收集器将仅在显式调用时运行，直到调用重启它。
+* `"restart"`：重启垃圾收集器的自动执行。
+* `"count"`：返回 Lua 使用的总内存数（以 K 字节为单位）。该值有小数部分，因此乘以 1024 即可得到 Lua 使用的精确字节数（除溢出外）。
+* `"step"`：执行一次垃圾收集步骤。步骤的"大小"由 arg 控制。值为零时，收集器将执行一个基本（不可分割的）步骤。对于非零值，收集器的行为就像 Lua 分配了相应数量的内存（以 K 字节为单位）。如果步骤完成了一个收集周期则返回 true。
+* `"setpause"`：将 arg 设置为收集器间歇率的新值（参见 §2.5）。返回间歇率的先前值。
+* `"setstepmul"`：将 arg 设置为收集器步进倍率的新值（参见 §2.5）。返回步进倍率的先前值。
+* "isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未停止）。
+]]
+
+collectgarbage54    =
+[[
+此函数是垃圾收集器的通用接口。根据其第一个参数 opt 执行不同的功能：
+
+* `"collect"`：执行一个完整的垃圾收集周期。这是默认选项。
+* `"stop"`：停止垃圾收集器的自动执行。收集器将仅在显式调用时运行，直到调用重启它。
+* `"restart"`：重启垃圾收集器的自动执行。
+* `"count"`：返回 Lua 使用的总内存数（以 K 字节为单位）。该值有小数部分，因此乘以 1024 即可得到 Lua 使用的精确字节数。
+* `"step"`：执行一次垃圾收集步骤。步骤的"大小"由 arg 控制。值为零时，收集器将执行一个基本（不可分割的）步骤。对于非零值，收集器的行为就像 Lua 分配了相应数量的内存（以 K 字节为单位）。如果步骤完成了一个收集周期则返回 true。
+* `"isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未停止）。
+* `"incremental"`：将收集器模式更改为增量模式。此选项后可以跟三个数字：垃圾收集器间歇率、步进倍率和步进大小（参见 §2.5.1）。零表示不更改该值。
+* `"generational"`：将收集器模式更改为分代模式。此选项后可以跟两个数字：垃圾收集器次要乘数和主要乘数（参见 §2.5.2）。零表示不更改该值。
+有关垃圾收集和其中一些选项的更多详细信息，请参见 §2.5。
+
+终结器不应调用此函数。
+]]
+
+collectgarbage55    =
+[[
+此函数是垃圾收集器的通用接口。根据其第一个参数 opt 执行不同的功能：
+
+* `"collect"`：执行一个完整的垃圾收集周期。这是默认选项。
+* `"stop"`：停止垃圾收集器的自动执行。收集器将仅在显式调用时运行，直到调用重启它。
+* `"restart"`：重启垃圾收集器的自动执行。
+* `"count"`：返回 Lua 使用的总内存数（以 K 字节为单位）。该值有小数部分，因此乘以 1024 即可得到 Lua 使用的精确字节数。
+* `"step"`：执行一次垃圾收集步骤。此选项后可以跟一个额外参数，一个表示步进大小的整数。
+
+    如果大小为正数 n，收集器的行为就像分配了 n 个新字节。如果大小为零，收集器执行一个基本步骤。在增量模式下，基本步骤对应于当前步进大小。在分代模式下，基本步骤执行一次完整的次要收集，或者如果收集器已安排了增量步骤，则执行增量步骤。
+
+    在增量模式下，如果步骤完成了一个收集周期，函数返回 true。在分代模式下，如果步骤完成了一次主要收集，函数返回 true。
+
+* `"isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未停止）。
+* `"incremental"`：将收集器模式更改为增量模式并返回先前的模式。
+* `"generational"`：将收集器模式更改为分代模式并返回先前的模式。
+* `"param"`：更改和/或检索收集器参数的值。此选项后必须跟一个或两个额外参数：被更改或检索的参数名称（字符串）和该参数的可选新值，范围为 [0,100000] 的整数。第一个参数必须是以下值之一：
+    * `"minormul"`：次要乘数。
+    * `"majorminor"`：主要-次要乘数。
+    * `"minormajor"`：次要-主要乘数。
+    * `"pause"`：垃圾收集器间歇率。
+    * `"stepmul"`：步进倍率。
+    * `"stepsize"`：步进大小。
+
+    调用总是返回参数的先前值。如果调用未提供新值，则该值保持不变。
+
+    Lua 以压缩格式存储这些值，因此作为先前值返回的值可能不完全等于上次设置的值。
+
+有关垃圾收集和其中一些选项的更多详细信息，请参见 §2.5。
+
+终结器不应调用此函数。
 ]]
 
 dofile              =
@@ -664,6 +702,10 @@ string.dump                 =
 '返回包含有以二进制方式表示的（一个 *二进制代码块* ）指定函数的字符串。'
 string.find                 =
 '查找第一个字符串中匹配到的 `pattern`（参见 §6.4.1）。'
+string.find['>5.2']         =
+'在字符串中查找与 `pattern`（参见 §6.4.1）匹配的第一个部分。'
+string.find['=5.1']         =
+'在字符串中查找与 `pattern`（参见 §5.4.1）匹配的第一个部分。'
 string.format               =
 '返回不定数量参数的格式化版本，格式化串为第一个参数。'
 string.gmatch               =
@@ -681,6 +723,36 @@ string.gmatch               =
 ]]
 string.gsub                 =
 '将字符串 s 中，所有的（或是在 n 给出时的前 n 个） pattern （参见 §6.4.1）都替换成 repl ，并返回其副本。'
+string.gmatch['>5.2']       =
+[[
+返回一个迭代器函数。每次调用都会在字符串 s 上继续按 `pattern`（参见 §6.4.1）匹配，并返回下一组捕获值。
+
+例如，下面的循环会遍历字符串 s 中的所有单词，并逐行打印：
+```lua
+    s =
+"hello world from Lua"
+    for w in string.gmatch(s, "%a+") do
+        print(w)
+    end
+```
+]]
+string.gmatch['=5.1']       =
+[[
+返回一个迭代器函数。每次调用都会在字符串 s 上继续按 `pattern`（参见 §5.4.1）匹配，并返回下一组捕获值。
+
+例如，下面的循环会遍历字符串 s 中的所有单词，并逐行打印：
+```lua
+    s =
+"hello world from Lua"
+    for w in string.gmatch(s, "%a+") do
+        print(w)
+    end
+```
+]]
+string.gsub['>5.2']         =
+'返回字符串 s 的副本，其中所有（或在给出 n 时的前 n 个）`pattern`（参见 §6.4.1）都被 `repl` 替换。'
+string.gsub['=5.1']         =
+'返回字符串 s 的副本，其中所有（或在给出 n 时的前 n 个）`pattern`（参见 §5.4.1）都被 `repl` 替换。'
 string.len                  =
 '返回其长度。'
 string.lower                =
@@ -691,6 +763,14 @@ string.pack                 =
 '返回一个打包了（即以二进制形式序列化） v1, v2 等值的二进制字符串。 字符串 fmt 为打包格式（参见 §6.4.2）。'
 string.packsize             =
 [[返回以指定格式用 $string.pack 打包的字符串的长度。 格式化字符串中不可以有变长选项 's' 或 'z' （参见 §6.4.2）。]]
+string.match['>5.2']        =
+'在字符串中查找与 `pattern`（参见 §6.4.1）匹配的第一个部分。'
+string.match['=5.1']        =
+'在字符串中查找与 `pattern`（参见 §5.4.1）匹配的第一个部分。'
+string.pack['>5.2']         =
+'返回一个包含值 `v1`、`v2` 等，按照格式字符串 `fmt`（参见 §6.4.2）打包（即以二进制形式序列化）的二进制字符串。'
+string.packsize['>5.2']     =
+'返回使用指定格式字符串 `fmt`（参见 §6.4.2）调用 $string.pack 得到的字符串大小。'
 string.rep['>5.2']          =
 '返回 `n` 个字符串 `s` 以字符串 `sep` 为分割符连在一起的字符串。 默认的 `sep` 值为空字符串（即没有分割符）。 如果 `n` 不是正数则返回空串。'
 string.rep['<5.1']          =
